==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Output/oss/translations/oss_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<defaultcodec></defaultcodec>
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="30"/>
        <source>OSS Plugin</source>
        <translation>Modul OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>O modulu OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Výstupní modul Qmmp OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Autor: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Založeno na kódu Brada Hughese &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>OSS Plugin Settings</source>
        <translation>Nastavení pluginu OSS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Mixer device</source>
        <translation>Ovládání hlasitosti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="220"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>PCM over Master</source>
        <translation>PCM přes Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="277"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="284"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/Output/oss/translations/oss_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>Modul OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>O modulu OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Výstupní modul Qmmp OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Autor: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Založeno na kódu Brada Hughese &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>Nastavení pluginu OSS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="30"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Mixer device</source>
        <translation>Ovládání hlasitosti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="167"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>PCM over Master</source>
        <translation>PCM přes Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="231"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
